==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/FormalAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttribute;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class FormalAttributeSetImpl extends InstanceSet<FormalAttributeSet,FormalAttribute> implements FormalAttributeSet {

    // attributes
    @Override
    public void setIa_ID( UniqueId ref_Ia_ID ) throws XtumlException {
        for ( FormalAttribute formalattribute : this ) formalattribute.setIa_ID( ref_Ia_ID );
    }


    // selections
    @Override
    public ClassParticipantAttributeSet R947_is_a_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( FormalAttribute formalattribute : this ) classparticipantattributeset.add( formalattribute.R947_is_a_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }


    @Override
    public FormalAttribute nullElement() {
        return FormalAttributeImpl.EMPTY_FORMALATTRIBUTE;
    }

    @Override
    public FormalAttributeSet emptySet() {
      return new FormalAttributeSetImpl();
    }

    @Override
    public FormalAttributeSet value() {
        return this;
    }

    @Override
    public List<FormalAttribute> elements() {
        return Arrays.asList(toArray(new FormalAttribute[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/FormalAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttribute;
import io.ciera.tool.sql.ooaofooa.interaction.FormalAttributeSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FormalAttributeSetImpl extends InstanceSet<FormalAttributeSet,FormalAttribute> implements FormalAttributeSet {

    public FormalAttributeSetImpl() {
    }

    public FormalAttributeSetImpl(Comparator<? super FormalAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setIa_ID( UniqueId ref_Ia_ID ) throws XtumlException {
        for ( FormalAttribute formalattribute : this ) formalattribute.setIa_ID( ref_Ia_ID );
    }


    // selections
    @Override
    public ClassParticipantAttributeSet R947_is_a_ClassParticipantAttribute() throws XtumlException {
        ClassParticipantAttributeSet classparticipantattributeset = new ClassParticipantAttributeSetImpl();
        for ( FormalAttribute formalattribute : this ) classparticipantattributeset.add( formalattribute.R947_is_a_ClassParticipantAttribute() );
        return classparticipantattributeset;
    }


    @Override
    public FormalAttribute nullElement() {
        return FormalAttributeImpl.EMPTY_FORMALATTRIBUTE;
    }

    @Override
    public FormalAttributeSet emptySet() {
      return new FormalAttributeSetImpl();
    }

    @Override
    public FormalAttributeSet emptySet(Comparator<? super FormalAttribute> comp) {
      return new FormalAttributeSetImpl(comp);
    }

    @Override
    public FormalAttributeSet value() {
        return this;
    }

    @Override
    public List<FormalAttribute> elements() {
        return Arrays.asList(toArray(new FormalAttribute[0]));
    }

}
